==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/SyslogLoggingDestinationParametersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SyslogLoggingDestinationParametersFluent<A extends SyslogLoggingDestinationParametersFluent<A>> extends BaseFluent<A>{
  public SyslogLoggingDestinationParametersFluent() {
  }
  public SyslogLoggingDestinationParametersFluent(SyslogLoggingDestinationParameters instance) {
    instance = (instance != null ? instance : new SyslogLoggingDestinationParameters());

    if (instance != null) {
      this.withAddress(instance.getAddress());
      this.withFacility(instance.getFacility());
      this.withMaxLength(instance.getMaxLength());
      this.withPort(instance.getPort());
      this.withAddress(instance.getAddress());
      this.withFacility(instance.getFacility());
      this.withMaxLength(instance.getMaxLength());
      this.withPort(instance.getPort());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String address;
  private String facility;
  private Integer maxLength;
  private Integer port;
  private Map<String,Object> additionalProperties;
  public String getAddress() {
    return this.address;
  }
  public A withAddress(String address) {
    this.address=address; return (A) this;
  }
  public boolean hasAddress() {
    return this.address != null;
  }
  public String getFacility() {
    return this.facility;
  }
  public A withFacility(String facility) {
    this.facility=facility; return (A) this;
  }
  public boolean hasFacility() {
    return this.facility != null;
  }
  public Integer getMaxLength() {
    return this.maxLength;
  }
  public A withMaxLength(Integer maxLength) {
    this.maxLength=maxLength; return (A) this;
  }
  public boolean hasMaxLength() {
    return this.maxLength != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public boolean hasPort() {
    return this.port != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SyslogLoggingDestinationParametersFluent that = (SyslogLoggingDestinationParametersFluent) o;
    if (!java.util.Objects.equals(address, that.address)) return false;

    if (!java.util.Objects.equals(facility, that.facility)) return false;

    if (!java.util.Objects.equals(maxLength, that.maxLength)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(address,  facility,  maxLength,  port,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (address != null) { sb.append("address:"); sb.append(address + ","); }
    if (facility != null) { sb.append("facility:"); sb.append(facility + ","); }
    if (maxLength != null) { sb.append("maxLength:"); sb.append(maxLength + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-operator-6.9.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/SyslogLoggingDestinationParametersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SyslogLoggingDestinationParametersFluent<A extends SyslogLoggingDestinationParametersFluent<A>> extends BaseFluent<A>{
  public SyslogLoggingDestinationParametersFluent() {
  }
  
  public SyslogLoggingDestinationParametersFluent(SyslogLoggingDestinationParameters instance) {
    this.copyInstance(instance);
  }
  private String address;
  private String facility;
  private Integer maxLength;
  private Integer port;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SyslogLoggingDestinationParameters instance) {
    instance = (instance != null ? instance : new SyslogLoggingDestinationParameters());
  
    if (instance != null) {
        this.withAddress(instance.getAddress());
        this.withFacility(instance.getFacility());
        this.withMaxLength(instance.getMaxLength());
        this.withPort(instance.getPort());
        this.withAddress(instance.getAddress());
        this.withFacility(instance.getFacility());
        this.withMaxLength(instance.getMaxLength());
        this.withPort(instance.getPort());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getAddress() {
    return this.address;
  }
  
  public A withAddress(String address) {
    this.address=address; return (A) this;
  }
  
  public boolean hasAddress() {
    return this.address != null;
  }
  
  public String getFacility() {
    return this.facility;
  }
  
  public A withFacility(String facility) {
    this.facility=facility; return (A) this;
  }
  
  public boolean hasFacility() {
    return this.facility != null;
  }
  
  public Integer getMaxLength() {
    return this.maxLength;
  }
  
  public A withMaxLength(Integer maxLength) {
    this.maxLength=maxLength; return (A) this;
  }
  
  public boolean hasMaxLength() {
    return this.maxLength != null;
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SyslogLoggingDestinationParametersFluent that = (SyslogLoggingDestinationParametersFluent) o;
    if (!java.util.Objects.equals(address, that.address)) return false;
  
    if (!java.util.Objects.equals(facility, that.facility)) return false;
  
    if (!java.util.Objects.equals(maxLength, that.maxLength)) return false;
  
    if (!java.util.Objects.equals(port, that.port)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(address,  facility,  maxLength,  port,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (address != null) { sb.append("address:"); sb.append(address + ","); }
    if (facility != null) { sb.append("facility:"); sb.append(facility + ","); }
    if (maxLength != null) { sb.append("maxLength:"); sb.append(maxLength + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
